@@ -6,7 +6,8 @@ bilibili_api.video
 注意，同时存在 page_index 和 cid 的参数，两者至少提供一个。
 """
 
-from enum import Enum
+from ast import Bytes
+from enum import Enum 
 import re
 import datetime
 import asyncio
@@ -222,15 +223,16 @@ class Video:
         cid = page["cid"]
         return cid
 
-    async def get_download_url(self, page_index: int = None, cid: int = None):
+    async def get_download_url(self, page_index: int = None, cid: int = None, html5: bool=False):
         """
         获取视频下载信息。
 
         page_index 和 cid 至少提供其中一个，其中 cid 优先级最高
 
         Args:
-            page_index (int, optional): 分 P 号，从 0 开始。Defaults to None
-            cid        (int, optional): 分 P 的 ID。Defaults to None
+            page_index (int, optional) : 分 P 号，从 0 开始。Defaults to None
+            cid        (int, optional) : 分 P 的 ID。Defaults to None
+            html5      (bool, optional): 是否以 html5 平台访问，这样子能直接在网页中播放，但是链接少。
 
         Returns:
             dict: 调用 API 返回的结果。
@@ -242,14 +244,25 @@ class Video:
             cid = await self.__get_page_id_by_index(page_index)
 
         url = API["info"]["playurl"]["url"]
-        params = {
-            "avid": self.get_aid(),
-            "cid": cid,
-            "qn": "127",
-            "otype": "json",
-            "fnval": 4048,
-            "fourk": 1
-        }
+        if html5:
+            params = {
+                "avid": self.get_aid(),
+                "cid": cid,
+                "qn": "127",
+                "otype": "json",
+                "fnval": 4048,
+                "fourk": 1, 
+                "platform": "html5"
+            }
+        else:
+            params = {
+                "avid": self.get_aid(),
+                "cid": cid,
+                "qn": "127",
+                "otype": "json",
+                "fnval": 4048,
+                "fourk": 1, 
+            }
         return await request("GET", url, params=params, credential=self.credential)
 
     async def get_related(self):
@@ -423,6 +436,7 @@ class Video:
                     data['mtime'] = reader_.string()
                 elif t == 9:
                     data['extra'] = json.loads(reader_.string())
+
                 elif t == 10:
                     data['id_str'] = reader_.string()
                 else:
@@ -479,6 +493,36 @@ class Video:
                     continue
             return data
 
+        def read_image_danmakus(string: bytes):
+            image_list = []
+            reader_ = BytesReader(string)
+            while not reader_.has_end():
+                type_ = reader_.varint() >> 3
+                if type_ == 1:
+                    details_dict = {}
+                    details_dict['texts'] = []
+                    img_details = reader_.bytes_string()
+                    reader_details = BytesReader(img_details)
+                    while not reader_details.has_end():
+                        type_details = reader_details.varint() >> 3
+                        if type_details == 1:
+                            details_dict['texts'].append(reader_details.string())
+                        elif type_details == 2:
+                            details_dict['image'] = reader_details.string()
+                        elif type_details == 3:
+                            id_string = reader_details.bytes_string()
+                            id_reader = BytesReader(id_string)
+                            while not id_reader.has_end():
+                                type_id = id_reader.varint() >> 3
+                                if type_id == 2:
+                                    details_dict['id'] = id_reader.varint()
+                                else:
+                                    raise ResponseException("解析响应数据错误")
+                    image_list.append(details_dict)
+                else:
+                    raise ResponseException("解析响应数据错误")
+            return image_list
+
         while not reader.has_end():
             type_ = reader.varint() >> 3
 
@@ -507,11 +551,13 @@ class Video:
                     read_command_danmakus(reader.bytes_string()))
             elif type_ == 10:
                 json_data['dm_setting'] = read_settings(reader.bytes_string())
+            elif type_ == 12:
+                json_data['image_dms'] = read_image_danmakus(reader.bytes_string())
             else:
                 continue
         return json_data
 
-    async def get_danmakus(self, page_index: int = None, date: datetime.date = None, cid: int = None) -> list[Danmaku]:
+    async def get_danmakus(self, page_index: int = None, date: datetime.date = None, cid: int = None):
         """
         获取弹幕。
 
@@ -546,19 +592,18 @@ class Video:
             api = API["danmaku"]["get_history_danmaku"]
             params["date"] = date.strftime("%Y-%m-%d")
             params["type"] = 1
+            all_seg = 1
         else:
             api = API["danmaku"]["get_danmaku"]
-            # params["segment_index"] = 1
-            # view 信息
-            info = await self.get_info()
-            danmaku_number = info['stat']['danmaku']
+            view = await self.get_danmaku_view(cid=cid)
+            all_seg = view['dm_seg']['total']
 
-        danmakus: List[Danmaku] = []
-        cnt = 1
-        while True:
+        danmakus = []
+
+        for seg in range(all_seg):
             if date is None:
                 # 仅当获取当前弹幕时需要该参数
-                params['segment_index'] = cnt
+                params['segment_index'] = seg + 1
 
             req = await session.get(api["url"], params=params, headers={
                 "Referer": "https://www.bilibili.com",
@@ -568,11 +613,11 @@ class Video:
                 req.raise_for_status()
             except aiohttp.ClientResponseError as e:
                 raise NetworkException(e.status, e.message)
-            
-            if 'content-type' not in req.headers.keys():
+
+            if 'Content-Type' not in req.headers.keys():
                 break
             else:
-                content_type = req.headers['content-type']
+                content_type = req.headers['Content-Type']
                 if content_type != 'application/octet-stream':
                     raise ResponseException("返回数据类型错误：")
 
@@ -587,18 +632,17 @@ class Video:
                 type_ = reader.varint() >> 3
                 if type_ != 1:
                     if type_ == 4:
-                        break
+                        reader.bytes_string()
+                        # 什么鬼？我用 protoc 解析出乱码！
                     else:
                         raise ResponseException("解析响应数据错误")
 
                 dm = Danmaku('')
                 dm_pack_data = reader.bytes_string()
                 dm_reader = BytesReader(dm_pack_data)
-                #print(type_)
 
                 while not dm_reader.has_end():
                     data_type = dm_reader.varint() >> 3
-                    #print("abc: ", data_type)
 
                     if data_type == 1:
                         dm.id = dm_reader.varint()
@@ -629,9 +673,6 @@ class Video:
                     else:
                         break
                 danmakus.append(dm)
-            if date:
-                break
-            cnt += 1
         return danmakus
 
     async def get_history_danmaku_index(self, page_index: int = None, date: datetime.date = None, cid: int = None):
